@@ -28,6 +28,7 @@ Field::type_map_gda_type_to_glom_type Field::m_map_gda_type_to_glom_type;
 Field::type_map_glom_type_to_gda_type Field::m_map_glom_type_to_gda_type;
 Field::type_map_type_names Field::m_map_type_names;
 Field::type_map_type_names Field::m_map_type_names_ui;
+Field::type_map_conversions Field::m_map_conversions;
 bool Field::m_maps_inited = false;
 
 
@@ -187,6 +188,7 @@ Glib::ustring Field::sql(const Gnome::Gda::Value& value) const
       case(TYPE_DATE):
       case(TYPE_TIME):
       case(TYPE_NUMERIC):
+      case(TYPE_IMAGE):
       {
         return "NULL";
         break;
@@ -240,6 +242,17 @@ Glib::ustring Field::sql(const Gnome::Gda::Value& value) const
 
       break;
     }
+    case(TYPE_IMAGE):
+    {
+      if(value.get_value_type() == Gnome::Gda::VALUE_TYPE_BINARY)
+      {
+        long buffer_size = 0;
+        const gpointer buffer = value.get_binary(&buffer_size);  
+        str = "'" + GlomConversions::get_escaped_binary_data((guint8*)buffer, buffer_size) + "'::bytea";
+      }
+      
+      break;
+    }
     default:
     {
       str = value.to_string();
@@ -420,31 +433,97 @@ void Field::init_map()
     m_map_gda_type_to_glom_type[Gnome::Gda::VALUE_TYPE_TIME] = TYPE_TIME;
     m_map_gda_type_to_glom_type[Gnome::Gda::VALUE_TYPE_DATE] = TYPE_DATE;
     m_map_gda_type_to_glom_type[Gnome::Gda::VALUE_TYPE_BOOLEAN] = TYPE_BOOLEAN;
-    
+    m_map_gda_type_to_glom_type[Gnome::Gda::VALUE_TYPE_BINARY] = TYPE_IMAGE;
+        
     m_map_glom_type_to_gda_type[TYPE_NUMERIC] = Gnome::Gda::VALUE_TYPE_NUMERIC;
     m_map_glom_type_to_gda_type[TYPE_TEXT] = Gnome::Gda::VALUE_TYPE_STRING;
     m_map_glom_type_to_gda_type[TYPE_TIME] = Gnome::Gda::VALUE_TYPE_TIME;
     m_map_glom_type_to_gda_type[TYPE_DATE] = Gnome::Gda::VALUE_TYPE_DATE;
     m_map_glom_type_to_gda_type[TYPE_BOOLEAN] = Gnome::Gda::VALUE_TYPE_BOOLEAN;
-    
+    m_map_glom_type_to_gda_type[TYPE_IMAGE] = Gnome::Gda::VALUE_TYPE_BINARY;
+        
     m_map_type_names_ui[TYPE_INVALID] = _("Invalid");
     m_map_type_names_ui[TYPE_NUMERIC] = _("Number");
     m_map_type_names_ui[TYPE_TEXT] = _("Text");
     m_map_type_names_ui[TYPE_TIME] = _("Time");
     m_map_type_names_ui[TYPE_DATE] = _("Date");    
     m_map_type_names_ui[TYPE_BOOLEAN] = _("Boolean");
+    m_map_type_names_ui[TYPE_IMAGE] = _("Image");
 
+    //Non-translated names used for the document:
     m_map_type_names[TYPE_INVALID] = "Invalid";
     m_map_type_names[TYPE_NUMERIC] = "Number";
     m_map_type_names[TYPE_TEXT] = "Text";
     m_map_type_names[TYPE_TIME] = "Time";
     m_map_type_names[TYPE_DATE] = "Date";
     m_map_type_names[TYPE_BOOLEAN] = "Boolean";
+    m_map_type_names[TYPE_IMAGE] = "Image";
     
+    
+    //Conversions:
+    //These are the conversions know to be supported by the used version of postgres
+    m_map_conversions.clear();
+  
+    type_list_conversion_targets list_conversions;
+  
+    //Numeric:
+    list_conversions.clear();
+    list_conversions.push_back(Field::TYPE_BOOLEAN);
+    list_conversions.push_back(Field::TYPE_TEXT);
+    list_conversions.push_back(Field::TYPE_DATE);
+    list_conversions.push_back(Field::TYPE_TIME);
+    m_map_conversions[Field::TYPE_NUMERIC] = list_conversions;
+    
+    //Text:
+    list_conversions.clear();
+    list_conversions.push_back(Field::TYPE_BOOLEAN);
+    list_conversions.push_back(Field::TYPE_NUMERIC);
+    list_conversions.push_back(Field::TYPE_DATE);
+    list_conversions.push_back(Field::TYPE_TIME);
+    m_map_conversions[Field::TYPE_TEXT] = list_conversions;
+    
+    //Boolean:
+    list_conversions.clear();
+    list_conversions.push_back(Field::TYPE_TEXT);
+    list_conversions.push_back(Field::TYPE_NUMERIC);
+    list_conversions.push_back(Field::TYPE_DATE);
+    list_conversions.push_back(Field::TYPE_TIME);
+    m_map_conversions[Field::TYPE_BOOLEAN] = list_conversions;
+    
+    //Date:
+    list_conversions.clear();
+    list_conversions.push_back(Field::TYPE_TEXT);
+    list_conversions.push_back(Field::TYPE_NUMERIC);
+    list_conversions.push_back(Field::TYPE_BOOLEAN);
+    m_map_conversions[Field::TYPE_DATE] = list_conversions;
+    
+    //Time:
+    list_conversions.clear();
+    list_conversions.push_back(Field::TYPE_TEXT);
+    list_conversions.push_back(Field::TYPE_NUMERIC);
+    list_conversions.push_back(Field::TYPE_BOOLEAN);
+    m_map_conversions[Field::TYPE_TIME] = list_conversions;
+    
+  
     m_maps_inited = true;
   }
 }
 
+//static:
+bool Field::get_conversion_possible(glom_field_type field_type_src, glom_field_type field_type_dest)
+{
+  type_map_conversions::const_iterator iterFind = m_map_conversions.find(field_type_src);
+  if(iterFind != m_map_conversions.end())
+  {
+    const type_list_conversion_targets list_conversions = iterFind->second;
+    type_list_conversion_targets::const_iterator iterConversionFind = std::find(list_conversions.begin(), list_conversions.end(), field_type_dest);
+    if(iterConversionFind != list_conversions.end())
+      return true; //Success: conversion found.
+  }
+  
+  return false; //failed.
+}
+
 //static:
 Field::type_map_type_names Field::get_type_names_ui()
 {
