@@ -23,6 +23,7 @@
 #include "comboentryglom.h"
 #include "comboglom.h"
 #include "textviewglom.h"
+#include "imageglom.h"
 #include "../data_structure/glomconversions.h"
 #include "../application.h"
 #include "../mode_data/dialog_choose_field.h"
@@ -42,6 +43,7 @@ DataWidget::DataWidget(const LayoutItem_Field& field, const Glib::ustring& table
   set_layout_item(field.clone(), table_name); //takes ownership
 
   Gtk::Widget* child = 0;
+  LayoutWidgetField* pFieldWidget = 0;
   const Glib::ustring title = field.get_title_or_name();
   if(glom_type == Field::TYPE_BOOLEAN)
   {
@@ -55,13 +57,29 @@ DataWidget::DataWidget(const LayoutItem_Field& field, const Glib::ustring& table
 
     m_label.set_text( Glib::ustring() ); //It is not used.
   }
+  else if(glom_type == Field::TYPE_IMAGE)
+  {
+    ImageGlom* image = Gtk::manage( new ImageGlom() );
+    image->set_size_request(200, 200);
+    //Gtk::Image* image = Gtk::manage( new Gtk::Image("/home/murrayc/gnome-small.jpg") );
+    image->show();
+    //TODO: Respond to double-click: checkbutton->signal_toggled().connect( sigc::mem_fun(*this, &DataWidget::on_widget_edited)  );
+
+    //TODO: entry->signal_user_requested_layout().connect( sigc::mem_fun(*this, &DataWidget::on_child_user_requested_layout );
+
+    child = image;
+    pFieldWidget = image;
+
+    m_label.set_label(title);
+    m_label.set_alignment(0);
+    m_label.show();
+  }
   else
   {
     m_label.set_label(title);
     m_label.set_alignment(0);
     m_label.show();
 
-    LayoutWidgetField* pFieldWidget = 0;
     //Use a Combo if there is a drop-down of choices (A "value list"), else an Entry:
     if(field.get_formatting_used().get_has_choices())
     {
@@ -140,7 +158,10 @@ DataWidget::DataWidget(const LayoutItem_Field& field, const Glib::ustring& table
 
       pFieldWidget->set_layout_item(get_layout_item()->clone(), table_name); //TODO_Performance: We only need this for the numerical format.
     }
-
+  }
+  
+  if(pFieldWidget)
+  {
     pFieldWidget->signal_edited().connect( sigc::mem_fun(*this, &DataWidget::on_widget_edited)  );
 
     pFieldWidget->signal_user_requested_layout().connect( sigc::mem_fun(*this, &DataWidget::on_child_user_requested_layout) );
@@ -150,7 +171,12 @@ DataWidget::DataWidget(const LayoutItem_Field& field, const Glib::ustring& table
 
     child = dynamic_cast<Gtk::Widget*>(pFieldWidget);
     int width = get_suitable_width(field);
-    child->set_size_request(width, -1 /* auto */);
+    
+    if(glom_type == Field::TYPE_IMAGE) //GtkImage widgets default to no size (invisible) if they are empty.
+      child->set_size_request(width, 200);
+    else
+      child->set_size_request(width, -1 /* auto */);
+      
     child->show_all();
   }
 
@@ -263,6 +289,11 @@ int DataWidget::get_suitable_width(const LayoutItem_Field& field_layout)
         example_text = "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA";
       break;
     }
+    case(Field::TYPE_IMAGE):
+    {
+      return 200;
+      break;
+    }
     default:
     {
       break;
